{% load redsolutioncms_tags %}{% raw %}{% extends "easy_news/base.html" %} {% load i18n %} {% block content_title %}{{ object.title }}{% endblock %} {% block content %}
{{ object.date|date:"d" }} {{ object.month }} {{ object.date|date:"Y" }}
{{ object.text|safe }}
{% trans 'All news' %}
{% endblock %} {% endraw %}{% if easy_news_settings.seo_was_installed %}{% raw %} {% load seo_tags %} {% block keywords %}{% seo keywords for object %}{% endblock %} {% block description %}{% seo description for object %}{% endblock %}" {% block title %}{% seo title for object as title %}{% if title %}{{ title }}{% else %}{{ object.title }}{% endif %}{% endblock %} {% endraw %}{% else %}{% raw %} {% block title %}{{ object.title }}{% endblock %} {% endraw %}{% endif %}{% if easy_news_settings.menu_proxy_was_installed %}{% raw %} {% load menuproxy_tags %} {% block main_menu %}{% show_main_menu 'news_detail' object %}{% endblock %} {% block auto_menu %}{% show_auto_menu 'news_detail' object %}{% endblock %} {% block full_menu %}{% show_full_menu 'news_detail' object %}{% endblock %} {% block breadcrumbs %}{% show_breadcrumbs 'news_detail' object %}{% endblock %} {% endraw %}{% endif %}